==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/67/67347dc9aea8908bd2ae8ab6e44f0908.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Integration/Interfaces/ConfigFormNotesInterface.php */
class __TwigTemplate_a2049d84ffdf218d32e0d9dd0d586fc5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Integration\\Interfaces;

use Mautic\\IntegrationsBundle\\DTO\\Note;

interface ConfigFormNotesInterface
{
    public function getAuthorizationNote(): ?Note;

    public function getFeaturesNote(): ?Note;

    public function getFieldMappingNote(): ?Note;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Integration/Interfaces/ConfigFormNotesInterface.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Integration/Interfaces/ConfigFormNotesInterface.php", "/var/www/mautic-ktn/app/bundles/IntegrationsBundle/Integration/Interfaces/ConfigFormNotesInterface.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/67/67347dc9aea8908bd2ae8ab6e44f0908.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Integration/Interfaces/ConfigFormNotesInterface.php */
class __TwigTemplate_a2049d84ffdf218d32e0d9dd0d586fc5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Integration\\Interfaces;

use Mautic\\IntegrationsBundle\\DTO\\Note;

interface ConfigFormNotesInterface
{
    public function getAuthorizationNote(): ?Note;

    public function getFeaturesNote(): ?Note;

    public function getFieldMappingNote(): ?Note;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Integration/Interfaces/ConfigFormNotesInterface.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Integration/Interfaces/ConfigFormNotesInterface.php", "/var/www/html/mauticGIT-Test/app/bundles/IntegrationsBundle/Integration/Interfaces/ConfigFormNotesInterface.php");
    }
}
